PCB Environment: ViewTab Class Reference

PCB Environment 2

Loading...
Searching...
No Matches
Public Slots | Public Member Functions
ViewTab Class Reference
Inheritance diagram for ViewTab:

## Public Slots
void | onLayerAlphaSlider (int layerIndex, int value)
void | onSlowdownSlider (int)
uint | slowdownToSliderPosition (uint us) const
void | onSave ()

## Public Member Functions
bool | init (GLWidget *)
void | setNumLayers (GLWidget *, uint)

The documentation for this class was generated from the following file:

- /home/chr/devel/PhD/Environment/pub/PCBEnv/pcbenv/cxx/UI/ViewTab.hpp